@@ -1127,7 +1127,7 @@ be called directly */
       
       /* mpn_lshift is faster still than mpn_add_n for adding a TypLimb
          number to itself                                                  */
-      if ( libGAP_EqInt( gmpL, gmpR ) ) {
+      if ( gmpL == gmpR ) {
         carry = mpn_lshift( libGAP_ADDR_INT(res),
                             libGAP_ADDR_INT(gmpL), libGAP_SIZE_INT(gmpL),
                             1 );
