@@ -138,6 +138,13 @@ libGAP_Obj            libGAP_RemList (
     libGAP_Int                 pos; 
     libGAP_Obj result;
     pos = libGAP_LEN_LIST( list ) ;
+    if ( pos == 0L ) {
+        list = libGAP_ErrorReturnObj(
+                "Remove: <list> must not be empty",
+                0L, 0L,
+                "you may replace <list> via 'return <list>;'" );
+        return libGAP_RemList(list);
+    }
     result = libGAP_ELM_LIST(list, pos);
     libGAP_UNB_LIST(list, pos);
     return result;
@@ -155,12 +162,19 @@ libGAP_Obj            libGAP_RemPlist (
 
     if ( ! libGAP_IS_MUTABLE_PLIST(list) ) {
         list = libGAP_ErrorReturnObj(
-                "Lists Assignment: <list> must be a mutable list",
+                "Remove: <list> must be a mutable list",
                 0L, 0L,
                 "you may replace <list> via 'return <list>;'" );
         return libGAP_FuncREM_LIST( 0, list);
     }
     pos = libGAP_LEN_PLIST( list );
+    if ( pos == 0L ) {
+        list = libGAP_ErrorReturnObj(
+                "Remove: <list> must not be empty",
+                0L, 0L,
+                "you may replace <list> via 'return <list>;'" );
+        return libGAP_FuncREM_LIST( 0, list);
+    }
     removed = libGAP_ELM_PLIST(list, pos);
     libGAP_SET_ELM_PLIST(list, pos, (libGAP_Obj)0L);
     libGAP_SET_LEN_PLIST(list, pos-1);
