@@ -189,7 +189,7 @@ libGAP_UInt            libGAP_RNamObj (
     }
 
     /* convert string object (empty string may have type T_PLIST)          */
-    else if ( libGAP_IsStringConv(obj) && libGAP_MUTABLE_TNUM(libGAP_TNUM_OBJ(obj))==libGAP_T_STRING ) {
+    else if ( libGAP_IsStringConv(obj) && libGAP_IS_STRING_REP(obj) ) {
         return libGAP_RNamName( libGAP_CSTR_STRING(obj) );
     }
 
