@@ -17,6 +17,8 @@
 **  except file/stream handling which is done in "sysfiles.h".
 */
 
+#define _GNU_SOURCE  /* is used for ptsname_r prototype etc. */
+
 #ifndef libGAP_GAP_SYSTEM_H
 #define libGAP_GAP_SYSTEM_H
 
@@ -67,8 +69,6 @@
 /* define to create functions PTR_BAG, etc instead of macros               */
 /* #undef DEBUG_FUNCTIONS_BAGS */
 
-/* define to debug the generational aspect of gasman                       */
-/* #undef DEBUG_DEADSONS_BAGS */
 
 /* define to debug masterpointers errors                                   */
 /* #undef DEBUG_MASTERPOINTERS */
